(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      7014,        220]
NotebookOptionsPosition[      6171,        188]
NotebookOutlinePosition[      6535,        204]
CellTagsIndexPosition[      6492,        201]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Load the LGSBloch package", "Text",
 CellChangeTimes->{{3.463860948625*^9, 3.463860956296875*^9}}],

Cell[BoxData[
 RowBox[{"<<", "AtomicDensityMatrix`LGSBloch`"}]], "Input"],

Cell["\<\
Generate the system of equations for the Na D2 line. (This can take a few \
minutes.)\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NaD2LGS", "=", 
   RowBox[{"GenerateLGSSystem", "[", "]"}]}], ";"}]], "Input"],

Cell["\<\
 If you like, you can save the generated data to a file, so that you can \
recall it in the next Mathematica session with \
Get[ToFileName[NotebookDirectory[],\[CloseCurlyDoubleQuote]NaD2LGS.mx\
\[CloseCurlyDoubleQuote]]], without having to compute it again.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Save", "[", 
  RowBox[{
   RowBox[{"ToFileName", "[", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<NaD2LGS.mx\>\""}], 
    "]"}], ",", "NaD2LGS"}], "]"}]], "Input"],

Cell[TextData[{
 "Run a test calculation of return flux (in ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"photons", "/", 
      StyleBox["s",
       FontSlant->"Plain"]}], "/", "sr"}], "/", 
    RowBox[{"(", 
     RowBox[{
      StyleBox["W",
       FontSlant->"Plain"], "/", 
      SuperscriptBox[
       StyleBox["m",
        FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") emitted in the mesosphere) for a cw laser. Result should be 262.095 if \
everything is working properly."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PsiMeso", "[", 
  RowBox[{"NaD2LGS", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"IMeso", "\[Rule]", "46.0"}], ",", 
     RowBox[{"RepumpFraction", "\[Rule]", "0.12"}], ",", 
     RowBox[{"BG", "\[Rule]", "BGParanal"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData["262.09476078028285`"], "Output"]
}, Open  ]],

Cell["\<\
Here are the default parameters for PsiMeso.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData["$DefaultLGSParameters"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"IMeso", "\[Rule]", "46.`"}], ",", 
   RowBox[{"RepumpFraction", "\[Rule]", "0.12`"}], ",", 
   RowBox[{"LightPolarization", "\[Rule]", "1.`"}], ",", 
   RowBox[{"LightWavelength", "\[Rule]", "5.89159`*^-7"}], ",", 
   RowBox[{"Phase", "\[Rule]", "0.`"}], ",", 
   RowBox[{"FWHMbw", "\[Rule]", "0.`"}], ",", 
   RowBox[{"\[CapitalDelta]fLaser", "\[Rule]", "0.`"}], ",", 
   RowBox[{"\[CapitalDelta]fLaserDabOff", "\[Rule]", "0.`"}], ",", 
   RowBox[{"LaserWidth", "\[Rule]", "0"}], ",", 
   RowBox[{"BG", "\[Rule]", "0.2275`"}], ",", 
   RowBox[{"Ta", "\[Rule]", "0.84`"}], ",", 
   RowBox[{"Temperature", "\[Rule]", "185.`"}], ",", 
   RowBox[{"SDampingTime", "\[Rule]", "0.000245`"}], ",", 
   RowBox[{"VccTime", "\[Rule]", "0.000035`"}], ",", 
   RowBox[{"HNa", "\[Rule]", "92000.`"}], ",", 
   RowBox[{"vrms\[Gamma]", "\[Rule]", "38.`"}], ",", 
   RowBox[{"RecoilShift", "\[Rule]", "314159.2653589793`"}], ",", 
   RowBox[{"VccRateFunction", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PLaunch", "\[Rule]", "20.`"}], ",", 
   RowBox[{"Zenith", "\[Rule]", "0.5235987755982989`"}], ",", 
   RowBox[{"Htele", "\[Rule]", "2650.`"}], ",", 
   RowBox[{"DLT", "\[Rule]", "0.4`"}], ",", 
   RowBox[{"\[Mu]LT", "\[Rule]", "1.3888888888888888`"}], ",", 
   RowBox[{"MsqrLT", "\[Rule]", "1.1`"}], ",", 
   RowBox[{"MagneticZenith", "\[Rule]", "1.5707963267948966`"}], ",", 
   RowBox[{"MagneticAzimuth", "\[Rule]", "1.5707963267948966`"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Atmospheric and Mesospheric Parameters:\n\tBG: Mesospheric geomagnetic \
field strength ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    StyleBox["G",
     FontSlant->"Plain"], "]"}], TraditionalForm]]],
 "\n\tTa: One-way transmission at \[Lambda] at zenith\n\tTemperature: \
Mesospheric temperature [K]\n\ttauCollMult: Multiplier for S- and v-damping \
collision times\n\tHNa: Altitude of sodium centroid above sea level [m]\n\t\
vrms\[Gamma]: rms velocity of diffusion effects [m/s], \[Gamma] = \
vrms\[Gamma] / (DLT/\[Mu]LT)"
}], "Text"],

Cell[TextData[{
 "Launch Telescope System (LTS) Parameters:\n\tPLaunch: Launched power [W]\n\t\
",
 "Zenith",
 ": Zenith angle [rad]\n\tHtele: Altitude of launch telescope above sea level \
[m]\n\tDLT: Launch telescope aperture [m]\n\t\[Mu]LT: Ratio of DLT to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", 
    SuperscriptBox["e", "2"]}], TraditionalForm]]],
 " lauch beam intensity diameter (not radius!), see Yura, Eq.(2.7)\n\tMsqrLT: \
",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "2"], TraditionalForm]]],
 " beam quality factor out of the launch telescope\n\tMagneticZenith, \
MagneticAzimuth: elevation and azimuth angles of B vector in a system where \
the laser points along z "
}], "Text"],

Cell[TextData[{
 "Numerical Parameters:\n\tIMesoMax: Maximum intensity in mesosphere. If set \
to zero, the routine determines it automatically  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{
     StyleBox["W",
      FontSlant->"Plain"], "/", 
     SuperscriptBox[
      StyleBox["m",
       FontSlant->"Plain"], "2"]}], "]"}], TraditionalForm]]],
 "\n\tIMesoInitial: Starting mesospheric laser intensity  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{
     StyleBox["W",
      FontSlant->"Plain"], "/", 
     SuperscriptBox[
      StyleBox["m",
       FontSlant->"Plain"], "2"]}], "]"}], TraditionalForm]]],
 "\n\tMaxStepRatio: controls intensity step size\n\tIMesoFactor: multiply \
peak intensity by this factor to compute maximum repository intensity\n\t\
NSamples: number of samples in repository"
}], "Text"]
},
WindowSize->{875, 797},
WindowMargins->{{Automatic, 96}, {Automatic, 44}},
ShowSelection->True,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 104, 1, 29, "Text"],
Cell[664, 23, 73, 1, 31, "Input"],
Cell[740, 26, 109, 3, 29, "Text"],
Cell[852, 31, 113, 3, 31, "Input"],
Cell[968, 36, 282, 5, 47, "Text"],
Cell[1253, 43, 213, 6, 31, "Input"],
Cell[1469, 51, 557, 19, 49, "Text"],
Cell[CellGroupData[{
Cell[2051, 74, 276, 7, 31, "Input"],
Cell[2330, 83, 46, 0, 30, "Output"]
}, Open  ]],
Cell[2391, 86, 68, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[2484, 92, 47, 0, 31, "Input"],
Cell[2534, 94, 1506, 29, 111, "Output"]
}, Open  ]],
Cell[4055, 126, 559, 13, 137, "Text"],
Cell[4617, 141, 709, 18, 157, "Text"],
Cell[5329, 161, 838, 25, 123, "Text"]
}
]
*)

(* End of internal cache information *)

